<p align="center">
    <img width="55%" src="https://github.com/amandeep1991/aiops/raw/master/resources/aiops.jpeg" />
</p>

<div style="align-content: center">
    <h3 align="center">Basic Utilities for aiops implementations</h3>
</div>

* aiops is a library of basic utilities (including pretrained models/pipelines) for aiops implementations.
* `aiops` extends PyTorch to provide text data processing functions.

## Installation 

Make sure you have Python 3.6+ and PyTorch 1.0+. You can then install `aiops` using
pip:

```python
pip install aiops
```

## Authors

- [Amandeep](https://github.com/amandeep1991) - Developer

## Citing

If you find aiops useful for an academic publication, then please use the following BibTeX to cite it:

```
@misc{pytorch-nlp,
  author = {Amandeep},
  title = {aiops: Basic utilities for aiops implementations},
  year = {2020},
  publisher = {GitHub},
  journal = {GitHub repository},
  howpublished = {\url{https://github.com/amandeep1991/aiops}},
}
```
